@@ -216,6 +216,7 @@ struct key_menu {
 #define MC_QUOTA	803
 #define MC_ADDHEADER	804
 #define MC_XOAUTH2	805
+#define MC_EXTERNAL	806
 
 
 /* Commands for S/MIME screens */
@@ -584,6 +585,7 @@ extern struct key_menu	cancel_keymenu,
 			ans_certfail_keymenu,
 			ans_certquery_keymenu,
 			oauth2_auth_keymenu,
+			oauth2_device_auth_keymenu,
 			forge_keymenu,
 			listmgr_keymenu,
 			index_keymenu,
