@@ -1,7 +1,7 @@
 /*
  * Copyright 2016-2020 Eduardo Chappa
  *
- * Last Edited: July 21, 2018 Eduardo Chappa <chappa@washington.edu>
+ * Last Edited: January 26, 2020 Eduardo Chappa <chappa@washington.edu>
  *
  */
 /* ========================================================================
@@ -158,6 +158,8 @@
 #define SET_OA2CLIENTGETACCESSCODE (long) 170
 #define GET_OA2CLIENTINFO (long) 171
 #define SET_OA2CLIENTINFO (long) 172
+#define GET_OA2DEVICEINFO (long) 173
+#define SET_OA2DEVICEINFO (long) 174
 
 	/* 2xx: environment */
 #define GET_USERNAME (long) 201
@@ -192,8 +194,10 @@
 #define SET_EXTERNALAUTHID (long) 230
 #define GET_SSLCAPATH (long) 231
 #define SET_SSLCAPATH (long) 232
-#define GET_RESTRICTIONS (long) 233
-#define SET_RESTRICTIONS (long) 234
+#define GET_SSLCAFILE (long) 233
+#define SET_SSLCAFILE (long) 234
+#define GET_RESTRICTIONS (long) 235
+#define SET_RESTRICTIONS (long) 236
 
 	/* 3xx: TCP/IP */
 #define GET_OPENTIMEOUT (long) 300
@@ -296,6 +300,7 @@
 #define SET_IDLETIMEOUT (long) 453
 #define GET_FETCHLOOKAHEADLIMIT (long) 454
 #define SET_FETCHLOOKAHEADLIMIT (long) 455
+/* HTTP SUPPORT DEFINES THEIR OWN SET_ AND GET_ CONSTANTS (490..493). See http.h */
 
 	/* 5xx: local file drivers */
 #define GET_MBXPROTECTION (long) 500
@@ -546,6 +551,8 @@
 #define AU_HIDE (long) 0x10000000
 				/* authenticator disabled */
 #define AU_DISABLE (long) 0x20000000
+				/* can do single trip */
+#define AU_SINGLE (long) 0x40000000
 
 
 /* Garbage collection flags */
@@ -1375,11 +1382,11 @@ typedef long (*mailproxycopy_t) (MAILSTREAM *stream,char *sequence,
 typedef long (*tcptimeout_t) (long overall,long last, char *host);
 typedef long (*ucs4width_t) (unsigned long c);
 typedef void *(*authchallenge_t) (void *stream,unsigned long *len);
-typedef long (*authrespond_t) (void *stream,char *s,unsigned long size);
+typedef long (*authrespond_t) (void *stream,char *base,char *s,unsigned long size);
 typedef long (*authcheck_t) (void);
 typedef long (*authclient_t) (authchallenge_t challenger,
-			      authrespond_t responder,char *service,NETMBX *mb,
-			      void *s,unsigned long *trial,char *user);
+			      authrespond_t responder, char *base, char *service,NETMBX *mb,
+			      void *s, unsigned long port, unsigned long *trial,char *user);
 typedef char *(*authresponse_t) (void *challenge,unsigned long clen,
 				 unsigned long *rlen);
 typedef char *(*authserver_t) (authresponse_t responder,int argc,char *argv[]);
@@ -1911,20 +1918,30 @@ int PSOUT (char *s);
 int PSOUTR (SIZEDTEXT *s);
 int PFLUSH (void);
 
-/* XOAUTH Client-Side Support */
+/* XOAUTH2 and AUTHBEARER Client-Side Support */
 
 #define OA2NAME	"XOAUTH2"
+#define BEARERNAME "OAUTHBEARER"
 
 #define OAUTH2_MAX_EQUIV        (2)
 #define OAUTH2_TOT_EQUIV        (OAUTH2_MAX_EQUIV + 2)
 #define OAUTH2_PARAM_NUMBER	(7)
 
-typedef enum {OA2_Id = 0, OA2_Secret, OA2_Code, OA2_RefreshToken,
-	      OA2_Scope, OA2_Redirect,   
-	      OA2_GrantTypeforAccessToken, OA2_GrantTypefromRefreshToken,
-	      OA2_Response, OA2_State, OA2_Prompt, OA2_End} OA2_type;
+typedef enum {OA2_Id = 0,
+	      OA2_Secret,
+	      OA2_Code,
+	      OA2_RefreshToken,
+	      OA2_Scope,
+	      OA2_Redirect,
+	      OA2_GrantTypeforAccessToken,
+	      OA2_GrantTypefromRefreshToken,
+	      OA2_Response,
+	      OA2_State,
+	      OA2_DeviceCode,
+	      OA2_End} OA2_type;
 
-typedef enum {OA2_GetAccessCode = 0,
+typedef enum {OA2_GetAccessCode = 0,		/* define this to get access code */
+	      OA2_GetDeviceCode,		/* define this if server uses device */
 	      OA2_GetAccessTokenFromAccessCode,
 	      OA2_GetAccessTokenFromRefreshToken,
 	      OA2_GetEnd} OA2_function;
@@ -1936,20 +1953,43 @@ typedef struct OA2_param_s {
    
 typedef struct OA2_serverparam_s {
   char *name;         /* method name: GET or POST */
-  char *urlserver;
+  unsigned char *urlserver;
   OA2_type params[OAUTH2_PARAM_NUMBER];
 } OAUTH2_SERVER_METHOD_S;
 
+typedef struct device_code_s {
+  unsigned char *device_code;
+  unsigned char *user_code;
+  char *verification_uri;
+  int   expires_in;
+  int   interval;
+  unsigned char *message;
+} OAUTH2_DEVICECODE_S;
+
 typedef struct oauth2_s {
-   unsigned char *name;                          /* provider name */
-   char *host[OAUTH2_TOT_EQUIV];        /* servers for which this data applies  */
+   unsigned char *name;			/* provider name */
+   char *host[OAUTH2_TOT_EQUIV];	/* servers for which this data applies  */
    OAUTH2_PARAM_S param[OA2_End];	/* parameters name and values for this server */
 		/* servers, methods and parameters to retrieve access code and tokens */
    OAUTH2_SERVER_METHOD_S server_mthd[OA2_GetEnd];
+   OAUTH2_DEVICECODE_S devicecode;
    char *access_token;
    unsigned long expiration;
+   unsigned int first_time:1;	/* this is the first time we get credentials for this account */
+   unsigned int require_secret:1;	/* this server requires a client-secret */
 } OAUTH2_S;
 
-typedef char *(*oauth2getaccesscode_t) (char *url, OAUTH2_S *, int *);
-typedef void (*oauth2clientinfo_t)(char *name, char **id, char **secret);
+typedef struct deviceproc_s {
+  OAUTH2_S *xoauth2;		/* the full OAUTH2_S structure we need to update */
+  char code_success;		/* code to say we succeeded */
+  char code_failure;		/* code to say we failed */
+  char code_wait;		/* code to say keep waiting */
+} OAUTH2_DEVICEPROC_S;
 
+/* Supporting external functions for XOAUTH2 and OAUTHBEARER */
+typedef char *(*oauth2getaccesscode_t) (unsigned char *, char *, OAUTH2_S *, int *);
+typedef void (*oauth2clientinfo_t)(unsigned char *name, char **id, char **secret);
+typedef void (*oauth2deviceinfo_t)(OAUTH2_S *, char *method);
+void mm_login_oauth2_c_client_method (NETMBX *, char *, char *, OAUTH2_S *, unsigned long, int *);
+char *oauth2_generate_state(void);
+void oauth2deviceinfo_get_accesscode(void *, void *);
