@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: search.c 1266 2009-07-14 18:39:12Z hubert@u.washingt
 
 /*
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -100,7 +100,7 @@ EXTRAKEYS    menu_srchopt[] = {
 
 /*	string search input parameters	*/
 
-#define	PTBEG	1	/* leave the point at the begining on search */
+#define	PTBEG	1	/* leave the point at the beginning on search */
 #define	PTEND	2	/* leave the point at the end on search */
 
 #define NPMT (2*NLINE+32)
@@ -394,7 +394,7 @@ forwsearch(int f, int n)
 
     /*
      * This code is kind of dumb.  What I want is successive C-W 's to 
-     * move dot to successive occurences of the pattern.  So, if dot is
+     * move dot to successive occurrences of the pattern.  So, if dot is
      * already sitting at the beginning of the pattern, then we'll move
      * forward a char before beginning the search.  We'll let the
      * automatic wrapping handle putting the dot back in the right 
@@ -620,7 +620,7 @@ replace_pat(UCS *defpat, int *wrapt, int bsearch)
 	  case (CTRL|'X'):        /* toggle replace all option */
 	    if (repl_all){
 		repl_all = FALSE;
-		/* TRANSLATORS: abbreviation for Replace All occurences */
+		/* TRANSLATORS: abbreviation for Replace All occurrences */
 		menu_pat[0].label = N_("Repl All");
 	    }
 	    else{
@@ -1112,7 +1112,8 @@ readpattern(char *utf8prompt, int text_mode, int flags)
 }
 
 /* given a line, reverse its content */
-void reverse_line(LINE *l)
+void
+reverse_line(LINE *l)
 {
   int i, j, a;
   UCS u;
@@ -1165,7 +1166,8 @@ reverse_buffer(void)
 
 
 /* given a UCS4 string reverse its content */
-void reverse_ucs4(UCS *s)
+void
+reverse_ucs4(UCS *s)
 {
   int i, j;
   UCS u;
@@ -1190,7 +1192,7 @@ forscan(int *wrapt,	/* boolean indicating search wrapped */
 	LINE *limitp,	/* stop searching if reached */
 	int limito,	/* stop searching if reached */
 	int leavep)	/* place to leave point
-				PTBEG = begining of match
+				PTBEG = beginning of match
 				PTEND = at end of match		*/
 
 {
@@ -1312,13 +1314,13 @@ forscan(int *wrapt,	/* boolean indicating search wrapped */
 		  goto fail;
 	    }
 
-	    /* A SUCCESSFULL MATCH!!! */
+	    /* A SUCCESSFUL MATCH!!! */
 	    /* reset the global "." pointers */
 	    if (leavep == PTEND) {	/* at end of string */
 		curwp->w_dotp = matchline;
 		curwp->w_doto = matchoff - 1;
 	    }
-	    else {		/* at begining of string */
+	    else {		/* at beginning of string */
 		curwp->w_dotp = lastline;
 		curwp->w_doto = lastoff;
 	    }
