@@ -133,6 +133,12 @@
 #define VAR_COLOR_STYLE		     vars[V_COLOR_STYLE].current_val.p
 #define GLO_COLOR_STYLE		     vars[V_COLOR_STYLE].global_val.p
 #endif
+#if !defined(_WINDOWS) || defined(WINDOWS_LIBRESSL_CERTS)
+#define VAR_SSLCAPATH		     vars[V_SSLCAPATH].current_val.l
+#define GLO_SSLCAPATH		     vars[V_SSLCAPATH].global_val.l
+#define VAR_SSLCAFILE		     vars[V_SSLCAFILE].current_val.l
+#define GLO_SSLCAFILE		     vars[V_SSLCAFILE].global_val.l
+#endif
 #define VAR_INDEX_COLOR_STYLE	     vars[V_INDEX_COLOR_STYLE].current_val.p
 #define GLO_INDEX_COLOR_STYLE	     vars[V_INDEX_COLOR_STYLE].global_val.p
 #define VAR_TITLEBAR_COLOR_STYLE     vars[V_TITLEBAR_COLOR_STYLE].current_val.p
@@ -233,8 +239,6 @@
 #define GLO_OPENING_SEP		     vars[V_OPENING_SEP].global_val.p
 #define VAR_ABOOK_FORMATS	     vars[V_ABOOK_FORMATS].current_val.l
 #define VAR_INDEX_FORMAT	     vars[V_INDEX_FORMAT].current_val.p
-#define VAR_SLEEP		     vars[V_SLEEP].current_val.p
-#define GLO_SLEEP		     vars[V_SLEEP].global_val.p
 #define VAR_OVERLAP		     vars[V_OVERLAP].current_val.p
 #define GLO_OVERLAP		     vars[V_OVERLAP].global_val.p
 #define VAR_MAXREMSTREAM	     vars[V_MAXREMSTREAM].current_val.p
@@ -263,8 +267,10 @@
 #define GLO_REMOTE_ABOOK_HISTORY     vars[V_REMOTE_ABOOK_HISTORY].global_val.p
 #define VAR_REMOTE_ABOOK_VALIDITY    vars[V_REMOTE_ABOOK_VALIDITY].current_val.p
 #define GLO_REMOTE_ABOOK_VALIDITY    vars[V_REMOTE_ABOOK_VALIDITY].global_val.p
+#ifdef DF_ENCRYPTION_RANGE
 #define GLO_ENCRYPTION_RANGE         vars[V_ENCRYPTION_RANGE].global_val.p
 #define VAR_ENCRYPTION_RANGE	     vars[V_ENCRYPTION_RANGE].current_val.p
+#endif
   /* Elm style save is obsolete in Pine 3.81 (see saved msg name rule) */
 #define VAR_ELM_STYLE_SAVE           vars[V_ELM_STYLE_SAVE].current_val.p
 #define GLO_ELM_STYLE_SAVE           vars[V_ELM_STYLE_SAVE].global_val.p
@@ -470,6 +476,8 @@
 #define VAR_PROMPT_BACK_COLOR	     vars[V_PROMPT_BACK_COLOR].current_val.p
 #define VAR_VIEW_HDR_COLORS	     vars[V_VIEW_HDR_COLORS].current_val.l
 #define VAR_INDEX_TOKEN_COLORS	     vars[V_INDEX_TOKEN_COLORS].current_val.l
+#define VAR_HTML_DIRECTORY	     vars[V_HTML_DIRECTORY].current_val.p
+#define GLO_HTML_DIRECTORY	     vars[V_HTML_DIRECTORY].global_val.p
 #ifdef SMIME
 #define VAR_PUBLICCERT_DIR	     vars[V_PUBLICCERT_DIR].current_val.p
 #define GLO_PUBLICCERT_DIR	     vars[V_PUBLICCERT_DIR].global_val.p
@@ -681,10 +689,6 @@
  */
 #define Q_SUPP_LIMIT (4)
 #define Q_DEL_ALL    (-10)
-#define	SVAR_SLEEP(ps,n,e,el)	strtoval((ps)->VAR_SLEEP,		  \
-					 &(n), 60, 120, 0, (e),		  \
-					  (el), 			  \
-					 "Sleep-Interval-Length")
 #define	SVAR_OVERLAP(ps,n,e,el)	strtoval((ps)->VAR_OVERLAP,		  \
 					 &(n), 0, 20, 0, (e),		  \
 					  (el), 			  \
@@ -914,6 +918,10 @@ char     **get_supported_options(void);
 unsigned   reset_startup_rule(MAILSTREAM *);
 void	   free_pinerc_lines(PINERC_LINE **);
 void	   panic1(char *, char *);
+#if !defined(_WINDOWS) || defined(WINDOWS_LIBRESSL_CERTS)
+void	   set_system_certs_path(struct pine *);
+void	   set_system_certs_container(struct pine *);
+#endif
 
 /* mandatory to implement prototypes */
 int	   set_input_timeout(int);
