@@ -111,7 +111,6 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_MARGIN
 		, V_STATUS_MSG_DELAY
 		, V_ACTIVE_MSG_INTERVAL
-		, V_SLEEP
 		, V_MAILCHECK
 		, V_MAILCHECKNONCURR
 		, V_MAILDROPCHECK
@@ -125,6 +124,10 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_DOWNLOAD_CMD_PREFIX
 		, V_MAILCAP_PATH
 		, V_MIMETYPE_PATH
+#if !defined(_WINDOWS) || defined(WINDOWS_LIBRESSL_CERTS)
+		, V_SSLCAPATH
+		, V_SSLCAFILE
+#endif
 		, V_BROWSER
 		, V_HISTORY
 		, V_MAXREMSTREAM
@@ -171,7 +174,9 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_NEW_VER_QUELL
 		, V_DISABLE_DRIVERS
 		, V_DISABLE_AUTHS
+#ifdef DF_ENCRYPTION_RANGE
 		, V_ENCRYPTION_RANGE
+#endif
 		, V_REMOTE_ABOOK_METADATA
 		, V_REMOTE_ABOOK_HISTORY
 		, V_REMOTE_ABOOK_VALIDITY
@@ -287,6 +292,7 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_CURSOR_STYLE
 #endif
 #endif
+		, V_HTML_DIRECTORY
 #ifdef	SMIME
 		, V_PUBLICCERT_DIR
 		, V_PUBLICCERT_CONTAINER
@@ -457,6 +463,7 @@ typedef enum {
 	F_VIEW_SEL_URL_HOST,
 	F_SCAN_ADDR,
 	F_FORCE_ARROWS,
+	F_EXTERNAL_INLINE_IMAGES,
 	F_PREFER_PLAIN_TEXT,
 	F_QUELL_CHARSET_WARNING,
 	F_COPY_TO_TO_FROM,
